@@ -20,8 +20,9 @@ body_add_break <- function( x, pos = "after"){
 #' @inheritParams body_add_break
 #' @param src image filename, the basename of the file must not contain any blank.
 #' @param style paragraph style
-#' @param width height in inches
-#' @param height height in inches
+#' @param width height in units
+#' @param height height in units
+#' @param units one of c("in", "cm", "mm")
 #' @examples
 #' doc <- read_docx()
 #'
@@ -32,7 +33,7 @@ body_add_break <- function( x, pos = "after"){
 #'
 #' print(doc, target = tempfile(fileext = ".docx"))
 #' @family functions for adding content
-body_add_img <- function( x, src, style = NULL, width, height, pos = "after" ){
+body_add_img <- function( x, src, style = NULL, width, height, units = c("in", "cm", "mm"), pos = "after" ){
 
   if( is.null(style) )
     style <- x$default_styles$paragraph
@@ -55,7 +56,8 @@ body_add_img <- function( x, src, style = NULL, width, height, pos = "after" ){
 
   style_id <- get_style_id(data = x$styles, style=style, type = "paragraph")
 
-  ext_img <- external_img(new_src, width = width, height = height)
+  to_inches <- function(x) x/c(`in` = 1, cm = 2.54, mm = 2.54 * 10)[units]  
+  ext_img <- external_img(new_src, width = to_inches(width), height = to_inches(height))
   xml_elt <- runs_to_p_wml(ext_img, add_ns = TRUE, style_id = style_id)
   x <- docx_reference_img(x, new_src)
   xml_elt <- wml_link_images( x, xml_elt )
@@ -118,8 +120,9 @@ body_add_docx <- function( x, src, pos = "after" ){
 #' @inheritParams body_add_break
 #' @param value ggplot object
 #' @param style paragraph style
-#' @param width height in inches
-#' @param height height in inches
+#' @param width height in units
+#' @param height height in units
+#' @param units one of c("in", "cm", "mm")
 #' @param res resolution of the png image in ppi
 #' @param ... Arguments to be passed to png function.
 #' @importFrom grDevices png dev.off
@@ -136,19 +139,16 @@ body_add_docx <- function( x, src, pos = "after" ){
 #'   print(doc, target = tempfile(fileext = ".docx") )
 #' }
 #' @family functions for adding content
-body_add_gg <- function( x, value, width = 6, height = 5, res = 300, style = "Normal", ... ){
+body_add_gg <- function( x, value, width = 6, height = 5, units = c("in", "cm", "mm"), res = 300, style = "Normal", ... ){
 
   if( !requireNamespace("ggplot2") )
     stop("package ggplot2 is required to use this function")
 
   stopifnot(inherits(value, "gg") )
   file <- tempfile(fileext = ".png")
-  options(bitmapType='cairo')
-  png(filename = file, width = width, height = height, units = "in", res = res, ...)
-  print(value)
-  dev.off()
+  ggplot2::ggsave(file, value, width = width, height = height, units = units, dpi=res, ...)
   on.exit(unlink(file))
-  body_add_img(x, src = file, style = style, width = width, height = height)
+  body_add_img(x, src = file, style = style, width = width, height = height, units=units)
 }
 
 
@@ -287,6 +287,7 @@ body_add_fpar <- function( x, value, style = NULL, pos = "after" ){
 #' @param header display header if TRUE
 #' @param alignment columns alignement, argument length must match with columns length,
 #' values must be "l" (left), "r" (right) or "c" (center).
+#' @param stylenames columns styles defined by [table_stylenames()]
 #' @param first_row Specifies that the first column conditional formatting should be
 #' applied. Details for this and other conditional formatting options can be found
 #' at http://officeopenxml.com/WPtblLook.php.
@@ -307,13 +308,14 @@ body_add_fpar <- function( x, value, style = NULL, pos = "after" ){
 #' @family functions for adding content
 body_add_table <- function( x, value, style = NULL, pos = "after", header = TRUE,
                             alignment = NULL,
+                            stylenames = table_stylenames(),
                             first_row = TRUE, first_column = FALSE,
                             last_row = FALSE, last_column = FALSE,
                             no_hband = FALSE, no_vband = TRUE ){
 
   pt <- prop_table(
     style = style, layout = table_layout(),
-    width = table_width(),
+    width = table_width(), stylenames = stylenames,
     tcf = table_conditional_formatting(
       first_row = first_row, first_column = first_column,
       last_row = last_row, last_column = last_column,
