@@ -37,18 +37,17 @@ slip_in_seqfield <- function( x, str, style = NULL, pos = "after" ){
     style <- x$default_styles$character
 
   style_id <- get_style_id(data = x$styles, style=style, type = "character")
-
-  xml_elt_1 <- paste0(wml_with_ns("w:r"),
-                      sprintf("<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>", style_id),
-                      "<w:fldChar w:fldCharType=\"begin\" w:dirty=\"true\"/>",
+  xml_elt_1 <- paste0(wr_ns_yes,
+                      "<w:rPr/>",
+                      "<w:fldChar w:fldCharType=\"begin\"/>",
                       "</w:r>")
-  xml_elt_2 <- paste0(wml_with_ns("w:r"),
-                      sprintf("<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>", style_id),
-                      sprintf("<w:instrText xml:space=\"preserve\" w:dirty=\"true\">%s</w:instrText>", str ),
+  xml_elt_2 <- paste0(wr_ns_yes,
+                      "<w:rPr/>",
+                      sprintf("<w:instrText xml:space=\"preserve\">%s</w:instrText>", str ),
                       "</w:r>")
-  xml_elt_3 <- paste0(wml_with_ns("w:r"),
-                      sprintf("<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>", style_id),
-                      "<w:fldChar w:fldCharType=\"end\" w:dirty=\"true\"/>",
+  xml_elt_3 <- paste0(wr_ns_yes,
+                      "<w:rPr/>",
+                      "<w:fldChar w:fldCharType=\"end\"/>",
                       "</w:r>")
 
   if( pos == "after"){
@@ -90,10 +89,10 @@ slip_in_text <- function( x, str, style = NULL, pos = "after", hyperlink = NULL
   style_id <- get_style_id(data = x$styles, style=style, type = "character")
 
   if( is.null(hyperlink) ) {
-    xml_elt <- paste0( wml_with_ns("w:r"),
+    xml_elt <- paste0( wr_ns_yes,
                        "<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>",
                        "<w:t xml:space=\"preserve\">%s</w:t></w:r>")
-    xml_elt <- sprintf(xml_elt, style_id, htmlEscape(str))
+    xml_elt <- sprintf(xml_elt, style_id, htmlEscapeCopy(str))
   } else {
     hyperlink_id <- paste0("rId", x$doc_obj$relationship()$get_next_id())
     x$doc_obj$relationship()$add(
@@ -102,10 +101,10 @@ slip_in_text <- function( x, str, style = NULL, pos = "after", hyperlink = NULL
       target = hyperlink,
       target_mode = "External" )
 
-    xml_elt <- paste0( wml_with_ns("w:hyperlink r:id=\"%s\""),
+    xml_elt <- paste0( "<w:hyperlink r:id=\"%s\" xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\">",
                        "<w:r><w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>",
                        "<w:t xml:space=\"preserve\">%s</w:t></w:r></w:hyperlink>")
-    xml_elt <- sprintf(xml_elt, hyperlink_id, style_id, htmlEscape(str))
+    xml_elt <- sprintf(xml_elt, hyperlink_id, style_id, htmlEscapeCopy(str))
   }
 
   slip_in_xml(x = x, str = xml_elt, pos = pos)
@@ -124,7 +123,6 @@ slip_in_text <- function( x, str, style = NULL, pos = "after", hyperlink = NULL
 #' @param height height in inches
 #' @param pos where to add the new element relative to the cursor,
 #' "after" or "before".
-#' @importFrom xml2 as_xml_document xml_find_first
 #' @examples
 #' library(magrittr)
 #' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
@@ -144,15 +142,15 @@ slip_in_img <- function( x, src, style = NULL, width, height, pos = "after" ){
   style_id <- get_style_id(data = x$styles, style=style, type = "character")
 
   ext_img <- external_img(new_src, width = width, height = height)
-  xml_elt <- format(ext_img, type = "wml")
-  xml_elt <- paste0(wml_with_ns("w:p"), "<w:pPr/>", xml_elt, "</w:p>")
+  xml_elt <- to_wml(ext_img)
+  xml_elt <- paste0(wp_ns_yes, "<w:pPr/>", xml_elt, "</w:p>")
 
   x <- docx_reference_img(x, new_src)
   xml_elt <- wml_link_images( x, xml_elt )
 
   drawing_node <- xml_find_first(as_xml_document(xml_elt), "//w:r/w:drawing")
 
-  wml_ <- paste0(wml_with_ns("w:r"), "<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>%s</w:r>")
+  wml_ <- paste0(wr_ns_yes, "<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>%s</w:r>")
   xml_elt <- sprintf(wml_, style_id, as.character(drawing_node) )
 
   slip_in_xml(x = x, str = xml_elt, pos = pos)
@@ -161,7 +159,6 @@ slip_in_img <- function( x, src, style = NULL, width, height, pos = "after" ){
 
 #' @export
 #' @title add a wml string into a Word document
-#' @importFrom xml2 as_xml_document xml_find_first xml_add_child
 #' @description The function add a wml string into
 #' the document after, before or on a cursor location.
 #' @param x an rdocx object
